==> magento-module-saas-order-sync-1.1.0.zip: Api/OrderSync/OrderSyncInterface.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2023 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
namespace Magento\SaaSOrderSync\Api\OrderSync;

use JsonSerializable;

interface OrderSyncInterface extends JsonSerializable
{

    /**
     * @return string the synchronization id
     */
    public function getSyncId(): string;

    /**
     * @return string the 'from' date time in ISO8601 format used to filter orders by creation time
     */
    public function getCreatedFrom(): string;

    /**
     * @return string the 'to' date time in ISO8601 format used to filter orders by creation time
     */
    public function getCreatedTo(): string;

    /**
     * @return string the client who triggered the order sync
     */
    public function getClientCode(): string;

    /**
     * @return int the initial amount of orders estimated to be synchronized
     */
    public function getInitialCount(): int;

    /**
     * @return int the amount of orders processed at the current time (including errors)
     */
    public function getProcessedCount(): int;

    /**
     * @return int the amount of orders which failed to process
     */
    public function getErrorCount(): int;

    /**
     * @return string the status of the synchronization
     */
    public function getStatus(): string;
}

==> magento-module-saas-order-sync-1.3.0.zip: Api/OrderSync/OrderSyncInterface.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2023 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
namespace Magento\SaaSOrderSync\Api\OrderSync;

interface OrderSyncInterface
{

    /**
     * @return string the synchronization id
     */
    public function getSyncId(): string;

    /**
     * @return string the 'from' date time in ISO8601 format used to filter orders by creation time
     */
    public function getCreatedFrom(): string;

    /**
     * @return string the 'to' date time in ISO8601 format used to filter orders by creation time
     */
    public function getCreatedTo(): string;

    /**
     * @return string the client who triggered the order sync
     */
    public function getClientCode(): string;

    /**
     * @return int the initial amount of orders estimated to be synchronized
     */
    public function getInitialCount(): int;

    /**
     * @return int the amount of orders processed at the current time (including errors)
     */
    public function getProcessedCount(): int;

    /**
     * @return int the amount of orders which failed to process
     */
    public function getErrorCount(): int;

    /**
     * @return string the status of the synchronization
     */
    public function getStatus(): string;
}
